from ..base import AdyenServiceBase


class BusinessLinesApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(BusinessLinesApi, self).__init__(client=client)
        self.service = "legalEntityManagement"
        self.baseUrl = "https://kyc-test.adyen.com/lem/v3"

    def delete_business_line(self, id, idempotency_key=None, **kwargs):
        """
        Delete a business line
        """
        endpoint = self.baseUrl + f"/businessLines/{id}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_business_line(self, id, idempotency_key=None, **kwargs):
        """
        Get a business line
        """
        endpoint = self.baseUrl + f"/businessLines/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_business_line(self, request, id, idempotency_key=None, **kwargs):
        """
        Update a business line
        """
        endpoint = self.baseUrl + f"/businessLines/{id}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_business_line(self, request, idempotency_key=None, **kwargs):
        """
        Create a business line
        """
        endpoint = self.baseUrl + f"/businessLines"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestClient(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    lib_version = settings.LIB_VERSION



from ..base import AdyenServiceBase
from .api_credentials_company_level_api import APICredentialsCompanyLevelApi
from .api_credentials_merchant_level_api import APICredentialsMerchantLevelApi
from .api_key_company_level_api import APIKeyCompanyLevelApi
from .api_key_merchant_level_api import APIKeyMerchantLevelApi
from .account_company_level_api import AccountCompanyLevelApi
from .account_merchant_level_api import AccountMerchantLevelApi
from .account_store_level_api import AccountStoreLevelApi
from .allowed_origins_company_level_api import AllowedOriginsCompanyLevelApi
from .allowed_origins_merchant_level_api import AllowedOriginsMerchantLevelApi
from .android_files_company_level_api import AndroidFilesCompanyLevelApi
from .client_key_company_level_api import ClientKeyCompanyLevelApi
from .client_key_merchant_level_api import ClientKeyMerchantLevelApi
from .my_api_credential_api import MyAPICredentialApi
from .payment_methods_merchant_level_api import PaymentMethodsMerchantLevelApi
from .payout_settings_merchant_level_api import PayoutSettingsMerchantLevelApi
from .split_configuration_merchant_level_api import SplitConfigurationMerchantLevelApi
from .terminal_actions_company_level_api import TerminalActionsCompanyLevelApi
from .terminal_actions_terminal_level_api import TerminalActionsTerminalLevelApi
from .terminal_orders_company_level_api import TerminalOrdersCompanyLevelApi
from .terminal_orders_merchant_level_api import TerminalOrdersMerchantLevelApi
from .terminal_settings_company_level_api import TerminalSettingsCompanyLevelApi
from .terminal_settings_merchant_level_api import TerminalSettingsMerchantLevelApi
from .terminal_settings_store_level_api import TerminalSettingsStoreLevelApi
from .terminal_settings_terminal_level_api import TerminalSettingsTerminalLevelApi
from .terminals_terminal_level_api import TerminalsTerminalLevelApi
from .users_company_level_api import UsersCompanyLevelApi
from .users_merchant_level_api import UsersMerchantLevelApi
from .webhooks_company_level_api import WebhooksCompanyLevelApi
from .webhooks_merchant_level_api import WebhooksMerchantLevelApi


class AdyenManagementApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenManagementApi, self).__init__(client=client)
        self.api_credentials_company_level_api = APICredentialsCompanyLevelApi(client=client)
        self.api_credentials_merchant_level_api = APICredentialsMerchantLevelApi(client=client)
        self.api_key_company_level_api = APIKeyCompanyLevelApi(client=client)
        self.api_key_merchant_level_api = APIKeyMerchantLevelApi(client=client)
        self.account_company_level_api = AccountCompanyLevelApi(client=client)
        self.account_merchant_level_api = AccountMerchantLevelApi(client=client)
        self.account_store_level_api = AccountStoreLevelApi(client=client)
        self.allowed_origins_company_level_api = AllowedOriginsCompanyLevelApi(client=client)
        self.allowed_origins_merchant_level_api = AllowedOriginsMerchantLevelApi(client=client)
        self.android_files_company_level_api = AndroidFilesCompanyLevelApi(client=client)
        self.client_key_company_level_api = ClientKeyCompanyLevelApi(client=client)
        self.client_key_merchant_level_api = ClientKeyMerchantLevelApi(client=client)
        self.my_api_credential_api = MyAPICredentialApi(client=client)
        self.payment_methods_merchant_level_api = PaymentMethodsMerchantLevelApi(client=client)
        self.payout_settings_merchant_level_api = PayoutSettingsMerchantLevelApi(client=client)
        self.split_configuration_merchant_level_api = SplitConfigurationMerchantLevelApi(client=client)
        self.terminal_actions_company_level_api = TerminalActionsCompanyLevelApi(client=client)
        self.terminal_actions_terminal_level_api = TerminalActionsTerminalLevelApi(client=client)
        self.terminal_orders_company_level_api = TerminalOrdersCompanyLevelApi(client=client)
        self.terminal_orders_merchant_level_api = TerminalOrdersMerchantLevelApi(client=client)
        self.terminal_settings_company_level_api = TerminalSettingsCompanyLevelApi(client=client)
        self.terminal_settings_merchant_level_api = TerminalSettingsMerchantLevelApi(client=client)
        self.terminal_settings_store_level_api = TerminalSettingsStoreLevelApi(client=client)
        self.terminal_settings_terminal_level_api = TerminalSettingsTerminalLevelApi(client=client)
        self.terminals_terminal_level_api = TerminalsTerminalLevelApi(client=client)
        self.users_company_level_api = UsersCompanyLevelApi(client=client)
        self.users_merchant_level_api = UsersMerchantLevelApi(client=client)
        self.webhooks_company_level_api = WebhooksCompanyLevelApi(client=client)
        self.webhooks_merchant_level_api = WebhooksMerchantLevelApi(client=client)



from ..base import AdyenServiceBase


class WebhooksMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(WebhooksMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def remove_webhook(self, merchantId, webhookId, idempotency_key=None, **kwargs):
        """
        Remove a webhook
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks/{webhookId}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_all_webhooks(self, merchantId, idempotency_key=None, **kwargs):
        """
        List all webhooks
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_webhook(self, merchantId, webhookId, idempotency_key=None, **kwargs):
        """
        Get a webhook
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks/{webhookId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_webhook(self, request, merchantId, webhookId, idempotency_key=None, **kwargs):
        """
        Update a webhook
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks/{webhookId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def set_up_webhook(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Set up a webhook
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def generate_hmac_key(self, merchantId, webhookId, idempotency_key=None, **kwargs):
        """
        Generate an HMAC key
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks/{webhookId}/generateHmac"
        method = "POST"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def test_webhook(self, request, merchantId, webhookId, idempotency_key=None, **kwargs):
        """
        Test a webhook
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/webhooks/{webhookId}/test"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import Adyen
import unittest
from Adyen import settings
try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestThirdPartyPayout(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.platform = "test"
    client.review_payout_username = "YourReviewPayoutUser"
    client.review_payout_password = "YourReviewPayoutPassword"
    client.store_payout_username = "YourStorePayoutUser"
    client.store_payout_password = "YourStorePayoutPassword"
    payout_url = adyen.payout.initialization_api.baseUrl

    def test_confirm_success(self):
        request = {
            "merchantAccount": "YourMerchantAccount",
            "originalReference": "YourReference"
        }
        resp = 'test/mocks/payout/confirm-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.reviewing_api.confirm_third_party(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/confirmThirdParty',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword',
        )
        self.assertIsNotNone(result.message['pspReference'])
        expected = "[payout-confirm-received]"
        self.assertEqual(expected, result.message['resultCode'])

    def test_confirm_missing_reference(self):
        request = {
            "merchantAccount": "YourMerchantAccount",
            "originalReference": ""
        }
        resp = 'test/mocks/payout/confirm-missing-reference.json'
        self.adyen.client = self.test.create_client_from_file(500, request, resp)
        self.assertRaisesRegex(
            Adyen.AdyenAPICommunicationError,
            "AdyenAPICommunicationError:{'status': 500, 'errorCode': '702', 'message': \"Required field 'merchantAccount' is null\", 'errorType': 'validation'}",
            self.adyen.payout.reviewing_api.confirm_third_party,
            request
        )

    def test_decline_success(self):
        request = {
            "merchantAccount": "YourMerchantAccount",
            "originalReference": "YourReference"
        }
        resp = 'test/mocks/payout/decline-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.reviewing_api.decline_third_party(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/declineThirdParty',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword',
        )
        self.assertIsNotNone(result.message['pspReference'])
        expected = "[payout-decline-received]"
        self.assertEqual(expected, result.message['resultCode'])

    def test_decline_missing_reference(self):
        request = {
            "merchantAccount": "YourMerchantAccount",
            "originalReference": ""
        }
        resp = 'test/mocks/payout/decline-missing-reference.json'
        self.adyen.client = self.test.create_client_from_file(500, request, resp)
        self.assertRaisesRegex(
            Adyen.AdyenAPICommunicationError,
            "AdyenAPICommunicationError:{'status': 500, 'errorCode': '702', 'message': \"Required field 'merchantAccount' is null\", 'errorType': 'validation'}",
            self.adyen.payout.reviewing_api.confirm_third_party,
            request
        )

    def test_store_detail_bank_success(self):
        request = {
            "bank": {
                "bankName": "AbnAmro",
                "bic": "ABNANL2A",
                "countryCode": "NL",
                "iban": "NL32ABNA0515071439",
                "ownerName": "Adyen",
                "bankCity": "Amsterdam",
                "taxId": "bankTaxId"
            },
            "merchantAccount": "YourMerchantAccount",
            "recurring": {
                "contract": "PAYOUT"
            },
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref"
        }
        resp = 'test/mocks/payout/storeDetail-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.initialization_api.store_detail(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/storeDetail',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword'
        )
        self.assertIsNotNone(result.message['pspReference'])
        self.assertIsNotNone(result.message['recurringDetailReference'])
        expected = "Success"
        self.assertEqual(expected, result.message['resultCode'])

    def test_submit_success(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "reference": "payout-test", "recurring": {
                "contract": "PAYOUT"
            },
            "merchantAccount": "YourMerchantAccount",
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref",
            "selectedRecurringDetailReference": "LATEST"
        }
        resp = 'test/mocks/payout/submit-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.initialization_api.submit_third_party(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/submitThirdParty',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword'
        )
        self.assertIsNotNone(result.message['pspReference'])
        expected = "[payout-submit-received]"
        self.assertEqual(expected, result.message['resultCode'])

    def test_submit_invalid_recurring_reference(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "reference": "payout-test", "recurring": {
                "contract": "PAYOUT"
            },
            "merchantAccount": "YourMerchantAccount",
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref",
            "selectedRecurringDetailReference": "1234"
        }
        resp = 'test/mocks/payout/submit-invalid-reference.json'
        self.adyen.client = self.test.create_client_from_file(422, request, resp)
        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'errorCode': '800',"
            " 'message': 'Contract not found', 'errorType': 'validation'}",
            self.adyen.payout.initialization_api.submit_third_party,
            request
        )

    def test_store_detail_and_submit_missing_reference(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "merchantAccount": "YourMerchantAccount",
            "recurring": {
                "contract": "PAYOUT"
            },
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref",
            "bank": {
                "iban": "NL32ABNA0515071439",
                "ownerName": "Adyen",
                "countryCode": "NL",
            }
        }

        resp = 'test/mocks/payout/submit-missing-reference.json'
        self.adyen.client = self.test.create_client_from_file(422, request, resp)

        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'message': 'Contract not found',"
            " 'errorCode': '800', 'errorType': 'validation'}",
            self.adyen.payout.initialization_api.store_detail_and_submit_third_party,
            request
        )

    def test_store_detail_and_submit_missing_payment(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "merchantAccount": "YourMerchantAccount",
            "reference": "payout-test",
            "recurring": {
                "contract": "PAYOUT"
            },
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref"
        }
        resp = 'test/mocks/payout/storeDetailAndSubmit-missing-payment.json'
        self.adyen.client = self.test.create_client_from_file(422, request, resp)
        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'errorCode': '000',"
            " 'message': 'Please supply paymentDetails', 'errorType': 'validation'}",
            self.adyen.payout.initialization_api.store_detail_and_submit_third_party,
            request
        )

    def test_store_detail_and_submit_invalid_iban(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "merchantAccount": "YourMerchantAccount",
            "reference": "payout-test",
            "recurring": {
                "contract": "PAYOUT"
            },
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref",
            "bank": {
                "countryCode": "NL",
                "iban": "4111111111111111",
                "ownerName": "Adyen",
            }
        }
        resp = 'test/mocks/payout/storeDetailAndSubmit-invalid-iban.json'
        self.adyen.client = self.test.create_client_from_file(422, request, resp)
        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'errorCode': '161',"
            " 'message': 'Invalid iban', 'errorType': 'validation'}",
            self.adyen.payout.initialization_api.store_detail_and_submit_third_party,
            request
        )

    def test_store_detail_and_submit_card_success(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "merchantAccount": "YourMerchantAccount",
            "reference": "payout-test",
            "recurring": {
                "contract": "PAYOUT"
            },
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref",
            "card": {
                "number": "4111111111111111",
                "expiryMonth": "08",
                "expiryYear": "2018",
                "cvc": "737",
                "holderName": "John Smith"
            }
        }
        resp = 'test/mocks/payout/storeDetailAndSubmit-card-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.initialization_api.store_detail_and_submit_third_party(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/storeDetailAndSubmitThirdParty',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword'
        )
        self.assertIsNotNone(result.message['pspReference'])
        expected = "[payout-submit-received]"
        self.assertEqual(expected, result.message['resultCode'])

    def test_store_detail_and_submit_bank_success(self):
        request = {
            "amount": {
                "value": "100000",
                "currency": "EUR"
            },
            "bank": {
                "countryCode": "NL",
                "iban": "NL32ABNA0515071439",
                "ownerName": "Adyen",
            },
            "merchantAccount": "YourMerchantAccount",
            "recurring": {
                "contract": "PAYOUT"
            },
            "reference": "YourReference",
            "shopperEmail": "ref@email.com",
            "shopperReference": "ref"
        }
        resp = 'test/mocks/payout/storeDetailAndSubmit-bank-success.json'
        self.adyen.client = self.test.create_client_from_file(200, request, resp)
        result = self.adyen.payout.initialization_api.store_detail_and_submit_third_party(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.payout_url}/storeDetailAndSubmitThirdParty',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword'
        )
        self.assertIsNotNone(result.message['pspReference'])
        expected = "[payout-submit-received]"
        self.assertEqual(expected, result.message['resultCode'])


TestThirdPartyPayout.client.http_force = "requests"
suite = unittest.TestLoader().loadTestsFromTestCase(TestThirdPartyPayout)
unittest.TextTestRunner(verbosity=2).run(suite)
TestThirdPartyPayout.client.http_force = "pycurl"
TestThirdPartyPayout.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestThirdPartyPayout)
unittest.TextTestRunner(verbosity=2).run(suite)
TestThirdPartyPayout.client.http_force = "other"
TestThirdPartyPayout.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestThirdPartyPayout)
unittest.TextTestRunner(verbosity=2).run(suite)



from ..base import AdyenServiceBase


class AccountHoldersApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AccountHoldersApi, self).__init__(client=client)
        self.service = "balancePlatform"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/bcl/v2"

    def get_account_holder(self, id, idempotency_key=None, **kwargs):
        """
        Get an account holder
        """
        endpoint = self.baseUrl + f"/accountHolders/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_all_balance_accounts_of_account_holder(self, id, idempotency_key=None, **kwargs):
        """
        Get all balance accounts of an account holder
        """
        endpoint = self.baseUrl + f"/accountHolders/{id}/balanceAccounts"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_tax_form(self, id, idempotency_key=None, **kwargs):
        """
        Get a tax form
        """
        endpoint = self.baseUrl + f"/accountHolders/{id}/taxForms"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_account_holder(self, request, id, idempotency_key=None, **kwargs):
        """
        Update an account holder
        """
        endpoint = self.baseUrl + f"/accountHolders/{id}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_account_holder(self, request, idempotency_key=None, **kwargs):
        """
        Create an account holder
        """
        endpoint = self.baseUrl + f"/accountHolders"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class CapitalApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(CapitalApi, self).__init__(client=client)
        self.service = "transfers"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/btl/v4"

    def get_capital_account(self, idempotency_key=None, **kwargs):
        """
        Get a capital account
        """
        endpoint = self.baseUrl + f"/grants"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_grant_reference_details(self, id, idempotency_key=None, **kwargs):
        """
        Get grant reference details
        """
        endpoint = self.baseUrl + f"/grants/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def request_grant_payout(self, request, idempotency_key=None, **kwargs):
        """
        Request a grant payout
        """
        endpoint = self.baseUrl + f"/grants"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from .base import AdyenServiceBase


class AdyenTerminalApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenTerminalApi, self).__init__(client=client)
        self.service = "terminal"
        self.baseUrl = "https://postfmapi-test.adyen.com/postfmapi/terminal/v1"

    def assign_terminals(self, request, idempotency_key=None, **kwargs):
        """
        Assign terminals
        """
        endpoint = self.baseUrl + f"/assignTerminals"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def find_terminal(self, request, idempotency_key=None, **kwargs):
        """
        Get the account or store of a terminal
        """
        endpoint = self.baseUrl + f"/findTerminal"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_stores_under_account(self, request, idempotency_key=None, **kwargs):
        """
        Get the stores of an account
        """
        endpoint = self.baseUrl + f"/getStoresUnderAccount"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_terminal_details(self, request, idempotency_key=None, **kwargs):
        """
        Get the details of a terminal
        """
        endpoint = self.baseUrl + f"/getTerminalDetails"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_terminals_under_account(self, request, idempotency_key=None, **kwargs):
        """
        Get the list of terminals
        """
        endpoint = self.baseUrl + f"/getTerminalsUnderAccount"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase
from .business_lines_api import BusinessLinesApi
from .documents_api import DocumentsApi
from .hosted_onboarding_api import HostedOnboardingApi
from .legal_entities_api import LegalEntitiesApi
from .pci_questionnaires_api import PCIQuestionnairesApi
from .terms_of_service_api import TermsOfServiceApi
from .transfer_instruments_api import TransferInstrumentsApi


class AdyenLegalEntityManagementApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenLegalEntityManagementApi, self).__init__(client=client)
        self.business_lines_api = BusinessLinesApi(client=client)
        self.documents_api = DocumentsApi(client=client)
        self.hosted_onboarding_api = HostedOnboardingApi(client=client)
        self.legal_entities_api = LegalEntitiesApi(client=client)
        self.pci_questionnaires_api = PCIQuestionnairesApi(client=client)
        self.terms_of_service_api = TermsOfServiceApi(client=client)
        self.transfer_instruments_api = TransferInstrumentsApi(client=client)



import Adyen
from Adyen import settings
import unittest

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestManagement(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    management_url = adyen.management.my_api_credential_api.baseUrl

    def test_get_company_account(self):
        request = None
        id = "YOUR_COMPANY_ACCOUNT"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "get_company_account"
                                                              ".json")

        result = self.adyen.management.account_company_level_api.get_company_account(companyId=id)
        self.assertEqual(id, result.message['id'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.management_url}/companies/{id}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )

    def test_my_api_credential_api(self):
        request = {"domain": "YOUR_DOMAIN"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "post_me_allowed"
                                                              "_origins.json")
        result = self.adyen.management.my_api_credential_api.add_allowed_origin(request)
        originId = result.message['id']
        self.assertEqual("YOUR_DOMAIN", result.message['domain'])
        self.adyen.client = self.test.create_client_from_file(204, {},
                                                              "test/mocks/"
                                                              "management/"
                                                              "no_content.json")
        result = self.adyen.management.my_api_credential_api.remove_allowed_origin(originId)
        self.adyen.client.http_client.request.assert_called_once_with(
            'DELETE',
            f'{self.management_url}/me/allowedOrigins/{originId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )

    def test_update_a_store(self):
        request = {
            "address": {
                "line1": "1776 West Pinewood Avenue",
                "line2": "Heartland Building",
                "line3": "",
                "postalCode": "20251"
            }
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "update_a_store"
                                                              ".json")
        storeId = "YOUR_STORE_ID"
        merchantId = "YOUR_MERCHANT_ACCOUNT_ID"
        result = self.adyen.management.account_store_level_api.update_store(request, merchantId, storeId)
        self.adyen.client.http_client.request.assert_called_once_with(
            'PATCH',
            f'{self.management_url}/merchants/{merchantId}/stores/{storeId}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )
        self.assertEqual(storeId, result.message['id'])
        self.assertEqual("1776 West Pinewood Avenue", result.message['address']['line1'])

    def test_create_a_user(self):
        request = {
            "name": {
                "firstName": "John",
                "lastName": "Smith"
            },
            "username": "johnsmith",
            "email": "john.smith@example.com",
            "timeZoneCode": "Europe/Amsterdam",
            "roles": [
                "Merchant standard role",
                "Merchant admin"
            ],
            "associatedMerchantAccounts": [
                "YOUR_MERCHANT_ACCOUNT"
            ]
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "create_a_user"
                                                              ".json")
        companyId = "YOUR_COMPANY_ACCOUNT"
        result = self.adyen.management.users_company_level_api.create_new_user(request, companyId)
        self.assertEqual(request['name']['firstName'], result.message['name']['firstName'])
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.management_url}/companies/{companyId}/users',
            json=request,
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            xapikey="YourXapikey"
        )

    def test_get_list_of_android_apps(self):
        request = {}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "get_list_of"
                                                              "_android_apps"
                                                              ".json")
        companyId = "YOUR_COMPANY_ACCOUNT"
        result = self.adyen.management.android_files_company_level_api.list_android_apps(companyId)
        self.assertEqual("ANDA422LZ223223K5F694GCCF732K8", result.message['androidApps'][0]['id'])

    def test_query_paramaters(self):
        request = {}
        companyId = "YOUR_COMPANY_ACCOUNT"
        query_parameters = {
            'pageNumber': 1,
            'pageSize': 10

        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "management/"
                                                              "get_list_of_merchant_accounts.json")
        result = self.adyen.management.account_company_level_api. \
            list_merchant_accounts(companyId, query_parameters=query_parameters)
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.management_url}/companies/{companyId}/merchants?pageNumber=1&pageSize=10',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )



from ..base import AdyenServiceBase
from .capital_api import CapitalApi
from .transactions_api import TransactionsApi
from .transfers_api import TransfersApi


class AdyenTransfersApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenTransfersApi, self).__init__(client=client)
        self.capital_api = CapitalApi(client=client)
        self.transactions_api = TransactionsApi(client=client)
        self.transfers_api = TransfersApi(client=client)



import Adyen
import unittest

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestPayments(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.platform = "test"
    client.xapikey = ""

    def test_authorise_success_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "737",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertEqual("8/2018",
                         result.message['additionalData']['expiryDate'])
        self.assertEqual("411111",
                         result.message['additionalData']['cardBin'])
        self.assertEqual("1111",
                         result.message['additionalData']['cardSummary'])
        self.assertEqual("Holder",
                         result.message['additionalData']['cardHolderName'])
        self.assertEqual("true",
                         result.message['additionalData']['threeDOffered'])
        self.assertEqual("false",
                         result.message['additionalData']
                         ['threeDAuthenticated'])
        self.assertEqual("69746", result.message['authCode'])
        self.assertEqual(11, len(result.message['fraudResult']['results']))
        fraud_checks = result.message['fraudResult']['results']
        fraud_check_result = fraud_checks[0]['FraudCheckResult']
        self.assertEqual("CardChunkUsage", fraud_check_result['name'])
        self.assertEqual(8, fraud_check_result['accountScore'])
        self.assertEqual(2, fraud_check_result['checkId'])

    def test_authorise_error010_mocked(self):
        request = {}
        request['merchantAccount'] = "testaccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "737",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(403, request,
                                                              'test/mocks/'
                                                              'authorise-error'
                                                              '-010'
                                                              '.json')
        self.assertRaises(Adyen.AdyenAPIInvalidPermission,
                          self.adyen.payment.payments_api.authorise, request)

    def test_authorise_error_cvc_declined_mocked(self):
        request = {}
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              'cvc-declined'
                                                              '.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Refused", result.message['resultCode'])

    def test_authorise_success_3d_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        request['browserInfo'] = {
            "userAgent": "YourUserAgent",
            "acceptHeader": "YourAcceptHeader"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '-3d.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("RedirectShopper", result.message['resultCode'])
        self.assertIsNotNone(result.message['md'])
        self.assertIsNotNone(result.message['issuerUrl'])
        self.assertIsNotNone(result.message['paRequest'])

    def test_authorise_3d_success_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['md'] = "testMD"
        request['paResponse'] = "paresponsetest"
        request['browserInfo'] = {
            "userAgent": "YourUserAgent",
            "acceptHeader": "YourAcceptHeader"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise3d-'
                                                              'success.json')
        result = self.adyen.payment.payments_api.authorise3d(request)
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertIsNotNone(result.message['pspReference'])

    def test_authorise_cse_success_mocked(self):
        request = {}
        request['amount'] = {"value": "1234", "currency": "EUR"}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['additionalData'] = {
            "card.encrypted.json": "YourCSEToken"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '-cse.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Authorised", result.message['resultCode'])

    def test_authorise_cse_error_expired_mocked(self):
        request = {}
        request['amount'] = {"value": "1234", "currency": "EUR"}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['additionalData'] = {
            "card.encrypted.json": "YourCSEToken"
        }

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              'expired.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Refused", result.message['resultCode'])
        self.assertEqual("DECLINED Expiry Incorrect",
                         result.message['additionalData']['refusalReasonRaw'])

    def test_error_401_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(401, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              '010.json')
        self.assertRaisesRegex(Adyen.AdyenAPIAuthenticationError,
                                "AdyenAPIAuthenticationError:{'status': 403, 'errorCode': '010',"
                                " 'message': 'Not allowed', 'errorType': 'security',"
                                " 'pspReference': '8514836072314693'}",
                                self.adyen.payment.payments_api.authorise, request)


class TestPaymentsWithXapiKey(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.platform = "test"
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.xapikey = ""

    def test_authorise_success_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "737",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertEqual("8/2018",
                         result.message['additionalData']['expiryDate'])
        self.assertEqual("411111",
                         result.message['additionalData']['cardBin'])
        self.assertEqual("1111",
                         result.message['additionalData']['cardSummary'])
        self.assertEqual("Holder",
                         result.message['additionalData']['cardHolderName'])
        self.assertEqual("true",
                         result.message['additionalData']['threeDOffered'])
        self.assertEqual("false",
                         result.message['additionalData']
                         ['threeDAuthenticated'])
        self.assertEqual("69746", result.message['authCode'])
        self.assertEqual(11, len(result.message['fraudResult']['results']))
        fraud_checks = result.message['fraudResult']['results']
        fraud_check_result = fraud_checks[0]['FraudCheckResult']
        self.assertEqual("CardChunkUsage", fraud_check_result['name'])
        self.assertEqual(8, fraud_check_result['accountScore'])
        self.assertEqual(2, fraud_check_result['checkId'])

    def test_authorise_error010_mocked(self):
        request = {}
        request['merchantAccount'] = "testaccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "737",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(403, request,
                                                              'test/mocks/'
                                                              'authorise-error'
                                                              '-010'
                                                              '.json')
        self.assertRaises(Adyen.AdyenAPIInvalidPermission,
                          self.adyen.payment.payments_api.authorise, request)

    def test_authorise_error_cvc_declined_mocked(self):
        request = {}
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              'cvc-declined'
                                                              '.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Refused", result.message['resultCode'])

    def test_authorise_success_3d_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        request['browserInfo'] = {
            "userAgent": "YourUserAgent",
            "acceptHeader": "YourAcceptHeader"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '-3d.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("RedirectShopper", result.message['resultCode'])
        self.assertIsNotNone(result.message['md'])
        self.assertIsNotNone(result.message['issuerUrl'])
        self.assertIsNotNone(result.message['paRequest'])

    def test_authorise_3d_success_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['md'] = "testMD"
        request['paResponse'] = "paresponsetest"
        request['browserInfo'] = {
            "userAgent": "YourUserAgent",
            "acceptHeader": "YourAcceptHeader"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise3d-'
                                                              'success.json')
        result = self.adyen.payment.payments_api.authorise3d(request)
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertIsNotNone(result.message['pspReference'])

    def test_authorise_cse_success_mocked(self):
        request = {}
        request['amount'] = {"value": "1234", "currency": "EUR"}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['additionalData'] = {
            "card.encrypted.json": "YourCSEToken"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-success'
                                                              '-cse.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Authorised", result.message['resultCode'])

    def test_authorise_cse_error_expired_mocked(self):
        request = {}
        request['amount'] = {"value": "1234", "currency": "EUR"}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['additionalData'] = {
            "card.encrypted.json": "YourCSEToken"
        }

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              'expired.json')
        result = self.adyen.payment.payments_api.authorise(request)
        self.assertEqual("Refused", result.message['resultCode'])
        self.assertEqual("DECLINED Expiry Incorrect",
                         result.message['additionalData']['refusalReasonRaw'])

    def test_error_401_mocked(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['amount'] = {"value": "100000", "currency": "EUR"}
        request['reference'] = "123456"
        request['card'] = {
            "number": "5136333333333335",
            "expiryMonth": "08",
            "expiryYear": "2018",
            "cvc": "787",
            "holderName": "John Doe"
        }
        self.adyen.client = self.test.create_client_from_file(401, request,
                                                              'test/mocks/'
                                                              'authorise'
                                                              '-error-'
                                                              '010.json')
        self.assertRaisesRegex(Adyen.AdyenAPIAuthenticationError,
                                "AdyenAPIAuthenticationError:{'status': 403, 'errorCode': '010',"
                                " 'message': 'Not allowed', 'errorType': 'security',"
                                " 'pspReference': '8514836072314693'}",
                                self.adyen.payment.payments_api.authorise, request)


from ..base import AdyenServiceBase
from .modifications_api import ModificationsApi
from .payments_api import PaymentsApi


class AdyenPaymentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPaymentsApi, self).__init__(client=client)
        self.modifications_api = ModificationsApi(client=client)
        self.payments_api = PaymentsApi(client=client)



from ..base import AdyenServiceBase


class TransferRoutesApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(TransferRoutesApi, self).__init__(client=client)
        self.service = "balancePlatform"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/bcl/v2"

    def calculate_transfer_routes(self, request, idempotency_key=None, **kwargs):
        """
        Calculate transfer routes
        """
        endpoint = self.baseUrl + f"/transferRoutes/calculate"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from .base import AdyenBase
from .binlookup import AdyenBinlookupApi
from .checkout import AdyenCheckoutApi
from .payments import AdyenPaymentsApi
from .payouts import AdyenPayoutsApi
from .recurring import AdyenRecurringApi
from .terminal import AdyenTerminalApi
from .management import AdyenManagementApi
from .legalEntityManagement import AdyenLegalEntityManagementApi
from .dataProtection import AdyenDataProtectionApi
from .transfers import AdyenTransfersApi
from .storedValue import AdyenStoredValueApi
from .balancePlatform import AdyenBalancePlatformApi
from .disputes import AdyenDisputesApi



import Adyen
from Adyen import settings
import unittest

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest

from Adyen.exceptions import AdyenEndpointInvalidFormat


class TestDetermineUrl(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    checkout_url = adyen.checkout.classic_checkout_sdk_api.baseUrl
    checkout_version = checkout_url.split('/')[-1]
    payment_url = adyen.payment.payments_api.baseUrl
    payment_version = payment_url.split('/')[-1]
    binlookup_url = adyen.binlookup.baseUrl
    management_url = adyen.management.account_merchant_level_api.baseUrl

    def test_checkout_api_url_custom(self):
        self.client.live_endpoint_prefix = "1797a841fbb37ca7-AdyenDemo"
        url = self.adyen.client._determine_api_url("live", self.checkout_url + "/payments")
        self.assertEqual("https://1797a841fbb37ca7-AdyenDemo-checkout-"
                         f"live.adyenpayments.com/checkout/{self.checkout_version}/payments", url)

    def test_checkout_api_url(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url("test", self.checkout_url + "/payments/details")
        self.assertEqual(url, f"{self.checkout_url}/payments/details")

    def test_payments_invalid_platform(self):

        request = {
            'amount': {"value": "100000", "currency": "EUR"},
            "reference": "Your order number",
            'paymentMethod': {
                "type": "scheme",
                "number": "4111111111111111",
                "expiryMonth": "08",
                "expiryYear": "2018",
                "holderName": "John Smith",
                "cvc": "737"
            },
            'merchantAccount': "YourMerchantAccount",
            'returnUrl': "https://your-company.com/..."
        }

        self.client.platform = "live"
        self.client.live_endpoint_prefix = None

        try:
            self.adyen.checkout.payments_api.sessions(request)
        except AdyenEndpointInvalidFormat as error:
            self.assertIsNotNone(error)

    def test_pal_url_live_endpoint_prefix_live_platform(self):
        self.client.live_endpoint_prefix = "1797a841fbb37ca7-AdyenDemo"
        url = self.adyen.client._determine_api_url(
            "live", self.payment_url + "/payments"
        )
        self.assertEqual(
            url,
            ("https://1797a841fbb37ca7-AdyenDemo-pal-"
             f"live.adyenpayments.com/pal/servlet/Payment/{self.payment_version}/payments")
        )

    def test_pal_url_live_endpoint_prefix_test_platform(self):
        self.client.live_endpoint_prefix = "1797a841fbb37ca7-AdyenDemo"
        url = self.adyen.client._determine_api_url(
            "test", self.payment_url + "/payments"
        )
        self.assertEqual(
            url,
            f"{self.payment_url}/payments")

    def test_pal_url_no_live_endpoint_prefix_test_platform(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url(
            "test", self.payment_url + "/payments"
        )
        self.assertEqual(
            url,
            f"{self.payment_url}/payments")

    def test_binlookup_url_no_live_endpoint_prefix_test_platform(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url(
            "test", self.binlookup_url + "/get3dsAvailability"
        )
        self.assertEqual(
            url,
            f"{self.binlookup_url}/get3dsAvailability"
        )

    def test_checkout_api_url_orders(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url("test", self.checkout_url +
                                                   "/orders")
        self.assertEqual(url, f"{self.checkout_url}/orders")

    def test_checkout_api_url_order_cancel(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url("test", self.checkout_url + "/orders/cancel")
        self.assertEqual(url, f"{self.checkout_url}/orders/cancel")

    def test_checkout_api_url_order_payment_methods_balance(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url("test", self.checkout_url + "/paymentMethods/balance")
        self.assertEqual(url, f"{self.checkout_url}/paymentMethods/balance")

    def test_checkout_api_url_sessions(self):
        self.client.live_endpoint_prefix = None
        url = self.adyen.client._determine_api_url("test", self.checkout_url + "/sessions")
        self.assertEqual(url, f"{self.checkout_url}/sessions")

    def test_management_api_url_companies(self):
        companyId = "YOUR_COMPANY_ID"
        url = self.adyen.client._determine_api_url("test", self.management_url + f'/companies/{companyId}/users')
        self.assertEqual(url, f"{self.management_url}/companies/{companyId}/users")




try:
    import mock
except Exception:
    from unittest import mock
import json
from Adyen import httpclient


class BaseTest():
    def __init__(self, adyen):
        self.ady = adyen

    def create_client_from_file(self, status, request, filename=None):
        if filename:
            with open(filename) as data_file:
                data = json.load(data_file)
                st = open(filename)
                strjson = st.read()
        else:
            data = {}
            st = ""
            strjson = ""

        self.ady.client.http_client = httpclient.HTTPClient
        self.ady.client.http_init = True
        self.ady.client.http_client.request = mock.MagicMock(
            return_value=[strjson, request, status, data])

        mockclient = self.ady.client
        if st:
            st.close()
        return mockclient



import unittest
import Adyen
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest

REQUEST_KWARGS = {
    'merchantAccount': 'YourMerchantAccount',
    'amount': '1000'
}


class TestBinLookup(unittest.TestCase):
    ady = Adyen.Adyen()

    client = ady.client
    test = BaseTest(ady)
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.platform = "test"
    binLookup_version = ady.binlookup.baseUrl.split('/')[-1]

    def test_get_cost_estimate_success(self):
        self.ady.client.http_client.request.reset_mock()
        expected = {
            'cardBin': {
                'bin': '458012',
                'commercial': False,
                'fundingSource': 'CHARGE',
                'fundsAvailability': 'N',
                'issuingBank': 'Bank Of America',
                'issuingCountry': 'US', 'issuingCurrency': 'USD',
                'paymentMethod': 'Y',
                'summary': '6789'
            },
            'costEstimateAmount': {
                'currency': 'USD', 'value': 1234
            },
            'resultCode': 'Success',
            'surchargeType': 'PASSTHROUGH'
        }

        self.ady.client = self.test.create_client_from_file(
            status=200,
            request=REQUEST_KWARGS,
            filename='test/mocks/binlookup/getcostestimate-success.json'
        )

        result = self.ady.binlookup.get_cost_estimate(REQUEST_KWARGS)
        self.assertEqual(expected, result.message)
        self.ady.client.http_client.request.assert_called_once_with(
            'POST',
            'https://pal-test.adyen.com/pal/servlet/'
            f'BinLookup/{self.binLookup_version}/getCostEstimate',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                'merchantAccount': 'YourMerchantAccount',
                'amount': '1000',
                },
            password='YourWSPassword',
            username='YourWSUser'
        )

    def test_get_cost_estimate_error_mocked(self):
        self.ady.client = self.test.create_client_from_file(
            status=200,
            request=REQUEST_KWARGS,
            filename=(
                "test/mocks/binlookup/"
                "getcostestimate-error-invalid-data-422.json"
            )
        )

        result = self.ady.binlookup.get_cost_estimate(REQUEST_KWARGS)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("101", result.message['errorCode'])
        self.assertEqual("Invalid card number", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])


TestBinLookup.client.http_force = "requests"
suite = unittest.TestLoader().loadTestsFromTestCase(TestBinLookup)
unittest.TextTestRunner(verbosity=2).run(suite)
TestBinLookup.client.http_force = "pycurl"
TestBinLookup.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestBinLookup)
unittest.TextTestRunner(verbosity=2).run(suite)
TestBinLookup.client.http_force = "other"
TestBinLookup.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestBinLookup)
unittest.TextTestRunner(verbosity=2).run(suite)



import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestDisputes(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    disputes_url = adyen.disputes.baseUrl

    def test_accept_dispute(self):
        request = {
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-acceptDispute-accept-dispute-200.json")
        result = self.adyen.disputes.accept_dispute(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/acceptDispute',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_defend_dispute(self):
        request = {
            "defenseReasonCode": "SupplyDefenseMaterial",
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-defendDispute-defend-dispute-200.json")
        result = self.adyen.disputes.defend_dispute(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/defendDispute',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_delete_defense_dispute_document(self):
        request = {
            "defenseDocumentType": "DefenseMaterial",
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-deleteDisputeDefenseDocument-delete-dispute-defense-document-200.json")
        result = self.adyen.disputes.delete_dispute_defense_document(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/deleteDisputeDefenseDocument',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )        

    def test_download_dispute_defense_document(self):
        request = {
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-downloadDisputeDefenseDocument-download-dispute-defense-document-200.json")
        result = self.adyen.disputes.delete_dispute_defense_document(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/deleteDisputeDefenseDocument',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )        

    def test_retrieve_applicable_defense_reasons(self):
        request = {
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-retrieveApplicableDefenseReasons-retrieve-defense-reasons-200.json")
        result = self.adyen.disputes.retrieve_applicable_defense_reasons(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/retrieveApplicableDefenseReasons',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )       
         
    def test_supply_defense_document(self):
        request = {
            "defenseDocuments": [
                {
                    "content": "JVBERi0xLjQKJcOkw7zDtsOfCjIgMCBv+f/ub0j6JPRX+E3EmC==",
                    "contentType": "application/pdf",
                    "defenseDocumentTypeCode": "DefenseMaterial"
                }
            ],
            "disputePspReference": "DZ4DPSHB4WD2WN82",
            "merchantAccountCode": "YOUR_MERCHANT_ACCOUNT"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/disputes/"
                                                              "post-supplyDefenseDocument-supply-defense-document-200.json")
        result = self.adyen.disputes.supply_defense_document(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.disputes_url}/supplyDefenseDocument',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )        


import Adyen
import unittest
from Adyen import settings
try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestRecurring(unittest.TestCase):
    adyen = Adyen.Adyen()
    client = adyen.client
    test = BaseTest(adyen)
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.platform = "test"
    baseUrl = adyen.recurring.baseUrl

    def test_list_recurring_details(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request["shopperEmail"] = "ref@email.com"
        request["shopperReference"] = "ref"
        request['recurring'] = {}
        request["recurring"]['contract'] = "RECURRING"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'recurring/'
                                                            'listRecurring'
                                                            'Details-'
                                                            'success.json')
        result = self.adyen.recurring.list_recurring_details(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/listRecurringDetails',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword'
        )
        self.assertEqual(1, len(result.message['details']))
        self.assertEqual(1, len(result.message['details'][0]))
        recurringDetail = result.message['details'][0]['RecurringDetail']
        self.assertEqual("recurringReference",
                         recurringDetail['recurringDetailReference'])
        self.assertEqual("cardAlias", recurringDetail['alias'])
        self.assertEqual("1111", recurringDetail['card']['number'])

    def test_disable(self):
        request = {}
        request["shopperEmail"] = "ref@email.com"
        request["shopperReference"] = "ref"
        request["recurringDetailReference"] = "12345678889"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'recurring/'
                                                            'disable-success'
                                                            '.json')
        result = self.adyen.recurring.disable(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/disable',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            username='YourWSUser',
            password='YourWSPassword',
        )
        self.assertEqual(1, len(result.message['details']))
        self.assertEqual("[detail-successfully-disabled]",
                         result.message['response'])

    def test_disable_803(self):
        request = {}
        request["shopperEmail"] = "ref@email.com"
        request["shopperReference"] = "ref"
        request["recurringDetailReference"] = "12345678889"
        self.adyen.client = self.test.create_client_from_file(422, request,
                                                            'test/mocks/'
                                                            'recurring/'
                                                            'disable-error-803'
                                                            '.json')
        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'errorCode': '803', 'message': 'PaymentDetail not found', 'errorType': 'validation'}",
            self.adyen.recurring.disable,
            request
        )


TestRecurring.client.http_force = "requests"
suite = unittest.TestLoader().loadTestsFromTestCase(TestRecurring)
unittest.TextTestRunner(verbosity=2).run(suite)
TestRecurring.client.http_force = "pycurl"
TestRecurring.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestRecurring)
unittest.TextTestRunner(verbosity=2).run(suite)
TestRecurring.client.http_force = "other"
TestRecurring.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestRecurring)
unittest.TextTestRunner(verbosity=2).run(suite)



from ..base import AdyenServiceBase


class AccountMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AccountMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def list_merchant_accounts(self, idempotency_key=None, **kwargs):
        """
        Get a list of merchant accounts
        """
        endpoint = self.baseUrl + f"/merchants"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_merchant_account(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a merchant account
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_merchant_account(self, request, idempotency_key=None, **kwargs):
        """
        Create a merchant account
        """
        endpoint = self.baseUrl + f"/merchants"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def request_to_activate_merchant_account(self, merchantId, idempotency_key=None, **kwargs):
        """
        Request to activate a merchant account
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/activate"
        method = "POST"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class PaymentInstrumentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PaymentInstrumentsApi, self).__init__(client=client)
        self.service = "balancePlatform"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/bcl/v2"

    def get_payment_instrument(self, id, idempotency_key=None, **kwargs):
        """
        Get a payment instrument
        """
        endpoint = self.baseUrl + f"/paymentInstruments/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_network_tokens(self, id, idempotency_key=None, **kwargs):
        """
        List network tokens
        """
        endpoint = self.baseUrl + f"/paymentInstruments/{id}/networkTokens"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_pan_of_payment_instrument(self, id, idempotency_key=None, **kwargs):
        """
        Get the PAN of a payment instrument
        """
        endpoint = self.baseUrl + f"/paymentInstruments/{id}/reveal"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_all_transaction_rules_for_payment_instrument(self, id, idempotency_key=None, **kwargs):
        """
        Get all transaction rules for a payment instrument
        """
        endpoint = self.baseUrl + f"/paymentInstruments/{id}/transactionRules"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_payment_instrument(self, request, id, idempotency_key=None, **kwargs):
        """
        Update a payment instrument
        """
        endpoint = self.baseUrl + f"/paymentInstruments/{id}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_payment_instrument(self, request, idempotency_key=None, **kwargs):
        """
        Create a payment instrument
        """
        endpoint = self.baseUrl + f"/paymentInstruments"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class InitializationApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(InitializationApi, self).__init__(client=client)
        self.service = "payouts"
        self.baseUrl = "https://pal-test.adyen.com/pal/servlet/Payout/v68"

    def store_detail(self, request, idempotency_key=None, **kwargs):
        """
        Store payout details
        """
        endpoint = self.baseUrl + f"/storeDetail"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def store_detail_and_submit_third_party(self, request, idempotency_key=None, **kwargs):
        """
        Store details and submit a payout
        """
        endpoint = self.baseUrl + f"/storeDetailAndSubmitThirdParty"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def submit_third_party(self, request, idempotency_key=None, **kwargs):
        """
        Submit a payout
        """
        endpoint = self.baseUrl + f"/submitThirdParty"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class PaymentLinksApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PaymentLinksApi, self).__init__(client=client)
        self.service = "checkout"
        self.baseUrl = "https://checkout-test.adyen.com/v71"

    def get_payment_link(self, linkId, idempotency_key=None, **kwargs):
        """
        Get a payment link
        """
        endpoint = self.baseUrl + f"/paymentLinks/{linkId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_payment_link(self, request, linkId, idempotency_key=None, **kwargs):
        """
        Update the status of a payment link
        """
        endpoint = self.baseUrl + f"/paymentLinks/{linkId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def payment_links(self, request, idempotency_key=None, **kwargs):
        """
        Create a payment link
        """
        endpoint = self.baseUrl + f"/paymentLinks"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import unittest

import Adyen
from Adyen import settings
try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestCheckoutUtility(unittest.TestCase):
    ady = Adyen.Adyen()

    client = ady.client
    test = BaseTest(ady)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    checkout_url = ady.checkout.classic_checkout_sdk_api.baseUrl

    def test_origin_keys_success_mocked(self):
        request = {
            "originDomains": {
                "https://www.your-domain1.com",
                "https://www.your-domain2.com",
                "https://www.your-domain3.com"
            }
        }

        self.ady.client = self.test.create_client_from_file(200, request,
                                                            "test/mocks/"
                                                            "checkoututility/"
                                                            "originkeys"
                                                            "-success.json")
        result = self.ady.checkout.utility_api.origin_keys(request)

        self.assertEqual("pub.v2.7814286629520534.aHR0cHM6Ly93d3cu"
                         "eW91ci1kb21haW4xLmNvbQ.UEwIBmW9-c_uXo5wS"
                         "Er2w8Hz8hVIpujXPHjpcEse3xI",
                         result.message['originKeys']
                         ['https://www.your-domain1.com'])

        self.assertEqual("pub.v2.7814286629520534.aHR0cHM6Ly93d3cu"
                         "eW91ci1kb21haW4zLmNvbQ.fUvflu-YIdZSsLEH8"
                         "Qqmr7ksE4ag_NYiiMXK0s6aq_4",
                         result.message['originKeys']
                         ['https://www.your-domain3.com'])

        self.assertEqual("pub.v2.7814286629520534.aHR0cHM6Ly93d3cue"
                         "W91ci1kb21haW4yLmNvbQ.EP6eXBJKk0t7-QIUl6e_"
                         "b1qMuMHGepxG_SlUqxAYrfY",
                         result.message['originKeys']
                         ['https://www.your-domain2.com'])

    def test_checkout_utility_api_url_custom(self):
        url = self.ady.client._determine_api_url("test", self.checkout_url + "/originKeys")

        self.assertEqual(url, f"{self.checkout_url}/originKeys")

    def test_applePay_session(self):
        request = {
          "displayName": "YOUR_MERCHANT_NAME",
          "domainName": "YOUR_DOMAIN_NAME",
          "merchantIdentifier": "YOUR_MERCHANT_ID"
        }
        self.ady.client = self.test.create_client_from_file(200, request, "test/mocks/"
                                                                            "checkoututility/"
                                                                            "applepay-sessions"
                                                                            "-success.json")
        result = self.ady.checkout.utility_api.get_apple_pay_session(request)
        self.assertEqual("BASE_64_ENCODED_DATA", result.message['data'])



import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestCheckout(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    baseUrl = adyen.checkout.classic_checkout_sdk_api.baseUrl
    lib_version = settings.LIB_VERSION

    def test_payment_methods_success_mocked(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentmethods"
                                                              "-success.json")
        result = self.adyen.checkout.payments_api.payment_methods(request)
        self.assertEqual("AliPay", result.message['paymentMethods'][0]['name'])
        self.assertEqual("Credit Card",
                         result.message['paymentMethods'][2]['name'])
        self.assertEqual("Credit Card via AsiaPay",
                         result.message['paymentMethods'][3]['name'])

    def test_payment_methods_error_mocked(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentmethods-"
                                                              "error-forbidden"
                                                              "-403.json")
        result = self.adyen.checkout.payments_api.payment_methods(request)
        self.assertEqual(403, result.message['status'])
        self.assertEqual("901", result.message['errorCode'])
        self.assertEqual("Invalid Merchant Account", result.message['message'])
        self.assertEqual("security", result.message['errorType'])

    def test_payments_success_mocked(self):
        request = {'amount': {"value": "100000", "currency": "EUR"},
                   'reference': "123456", 'paymentMethod': {
                "type": "scheme",
                "number": "4111111111111111",
                "expiryMonth": "08",
                "expiryYear": "2018",
                "holderName": "John Smith",
                "cvc": "737"
            }, 'merchantAccount': "YourMerchantAccount",
                   'returnUrl': "https://your-company.com/..."}

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "payments"
                                                              "-success"
                                                              ".json")
        result = self.adyen.checkout.payments_api.payments(request)
        self.assertEqual("8535296650153317", result.message['pspReference'])
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertEqual("8/2018",
                         result.message["additionalData"]['expiryDate'])
        self.assertEqual("GREEN",
                         result.message["additionalData"]['fraudResultType'])

    def test_payments_error_mocked(self):
        request = {'amount': {"value": "100000", "currency": "EUR"},
                   'reference': "54431", 'paymentMethod': {
                "type": "scheme",
                "number": "4111111111111111",
                "expiryMonth": "08",
                "expiryYear": "2018",
                "holderName": "John Smith",
                "cvc": "737"
            }, 'merchantAccount': "YourMerchantAccount",
                   'returnUrl': "https://your-company.com/..."}

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "payments-error"
                                                              "-invalid"
                                                              "-data-422"
                                                              ".json")
        result = self.adyen.checkout.payments_api.payments(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/payments',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                'returnUrl': 'https://your-company.com/...',
                'reference': '54431',
                'merchantAccount': 'YourMerchantAccount',
                'amount': {'currency': 'EUR', 'value': '100000'},
                'paymentMethod': {
                    'expiryYear': '2018',
                    'holderName': 'John Smith',
                    'number': '4111111111111111',
                    'expiryMonth': '08',
                    'type': 'scheme',
                    'cvc': '737'
                }
            },
            xapikey='YourXapikey'
        )
        self.assertEqual(422, result.message['status'])
        self.assertEqual("130", result.message['errorCode'])
        self.assertEqual("Reference Missing", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_details_success_mocked(self):
        request = {'paymentData': "Hee57361f99....", 'details': {
            "MD": "sdfsdfsdf...",
            "PaRes": "sdkfhskdjfsdf..."
        }}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsdetails"
                                                              "-success.json")

        result = self.adyen.checkout.payments_api.payments_details(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/payments/details',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json={
                'paymentData': 'Hee57361f99....',
                'details': {'MD': 'sdfsdfsdf...', 'PaRes': 'sdkfhskdjfsdf...'}
            },
            xapikey='YourXapikey'
        )
        self.assertEqual("8515232733321252", result.message['pspReference'])
        self.assertEqual("Authorised", result.message['resultCode'])
        self.assertEqual("true",
                         result.message['additionalData']['liabilityShift'])
        self.assertEqual("AUTHORISED",
                         result.message['additionalData']['refusalReasonRaw'])

    def test_payments_details_error_mocked(self):
        request = {'paymentData': "Hee57361f99....", 'details': {
            "MD": "sdfsdfsdf...",
            "PaRes": "sdkfhskdjfsdf..."
        }}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsdetails"
                                                              "-error-invalid-"
                                                              "data-422.json")
        result = self.adyen.checkout.payments_api.payments_details(request)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("101", result.message['errorCode'])
        self.assertEqual("Invalid card number", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_session_success_mocked(self):
        request = {"reference": "Your order number",
                   "shopperReference": "yourShopperId_IOfW3k9G2PvXFu2j",
                   "channel": "iOS",
                   "token": "TOKEN_YOU_GET_FROM_CHECKOUT_SDK",
                   "returnUrl": "app://", "countryCode": "NL",
                   "shopperLocale": "nl_NL",
                   "sessionValidity": "2017-04-06T13:09:13Z",
                   "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                   'amount': {"value": "17408", "currency": "EUR"}}

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsession"
                                                              "-success.json")
        result = self.adyen.checkout.classic_checkout_sdk_api.payment_session(request)
        self.assertIsNotNone(result.message['paymentSession'])

    def test_payments_session_error_mocked(self):
        request = {"reference": "Your wro order number",
                   "shopperReference": "yourShopperId_IOfW3k9G2PvXFu2j",
                   "channel": "iOS",
                   "token": "WRONG_TOKEN",
                   "returnUrl": "app://", "countryCode": "NL",
                   "shopperLocale": "nl_NL",
                   "sessionValidity": "2017-04-06T13:09:13Z",
                   "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
                   'amount': {"value": "17408", "currency": "EUR"}}

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsession"
                                                              "-error-invalid-"
                                                              "data-422.json")
        result = self.adyen.checkout.classic_checkout_sdk_api.payment_session(request)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_012", result.message['errorCode'])
        self.assertEqual("The provided SDK token could not be parsed.",
                         result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_result_success_mocked(self):
        request = {"payload": "VALUE_YOU_GET_FROM_CHECKOUT_SDK"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult"
                                                              "-success.json")
        result = self.adyen.checkout.classic_checkout_sdk_api.verify_payment_result(request)
        self.assertEqual("8535253563623704", result.message['pspReference'])
        self.assertEqual("Authorised", result.message['resultCode'])

    def test_payments_result_error_mocked(self):
        request = {"payload": "VALUE_YOU_GET_FROM_CHECKOUT_SDK"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult"
                                                              "-error-invalid-"
                                                              "data-payload-"
                                                              "422.json")
        result = self.adyen.checkout.classic_checkout_sdk_api.verify_payment_result(request)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_cancels_without_reference(self):
        requests = {
            "paymentReference": "Payment123",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "reference": "YourCancelReference",
        }
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentscancel-"
                                                              "withoutreference-succes.json")
        results = self.adyen.checkout.modifications_api.cancel_authorised_payment(requests)
        self.assertIsNotNone(results.message['paymentReference'])
        self.assertEqual("8412534564722331", results.message['pspReference'])
        self.assertEqual("received", results.message['status'])

    def test_payments_cancels_without_reference_error_mocked(self):
        requests = {
            "paymentReference": "Payment123",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "reference": "YourCancelReference",
        }
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult"
                                                              "-error-invalid-"
                                                              "data-payload-"
                                                              "422.json")

        result = self.adyen.checkout.modifications_api.cancel_authorised_payment(requests)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_cancels_success_mocked(self):
        requests = {"reference": "Your wro order number", "merchantAccount": "YOUR_MERCHANT_ACCOUNT"}

        reference_id = "8836183819713023"
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentscancels"
                                                              "-success.json")
        result = self.adyen.checkout.modifications_api.refund_or_cancel_payment(requests, reference_id)
        self.assertEqual(reference_id, result.message["paymentPspReference"])
        self.assertEqual("received", result.message['status'])

    def test_payments_cancels_error_mocked(self):
        request = {"reference": "Your wro order number"}
        psp_reference = "8836183819713023"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult-error-invalid-"
                                                              "data-payload-422.json")
        result = self.adyen.checkout.modifications_api.refund_or_cancel_payment(request, psp_reference)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_refunds_success_mocked(self):
        requests = {
            "paymentReference": "Payment123",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "reference": "YourCancelReference",
        }
        psp_reference = "Payment123"
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentscancel-"
                                                              "withoutreference-succes.json")

        result = self.adyen.checkout.modifications_api.refund_captured_payment(requests,psp_reference)
        self.assertEqual(psp_reference, result.message["paymentReference"])
        self.assertIsNotNone(result.message["pspReference"])
        self.assertEqual("received", result.message['status'])

    def test_payments_refunds_error_mocked(self):
        requests = {
            "paymentReference": "Payment123",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "reference": "YourCancelReference",
        }
        reference_id = "Payment123"
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult-error-invalid-"
                                                              "data-payload-422.json")

        result = self.adyen.checkout.modifications_api.refund_captured_payment(requests, reference_id)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_reversals_success_mocked(self):
        requests = {
            "reference": "YourReversalReference",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT"
        }
        psp_reference = "8836183819713023"
        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsreversals-"
                                                              "success.json")

        result = self.adyen.checkout.modifications_api.refund_or_cancel_payment(requests, psp_reference)
        self.assertEqual(psp_reference, result.message["paymentPspReference"])
        self.assertIsNotNone(result.message["pspReference"])
        self.assertEqual("received", result.message['status'])

    def test_payments_reversals_failure_mocked(self):
        requests = {
            "reference": "YourReversalReference",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT"
        }
        psp_reference = "8836183819713023"

        self.adyen.client = self.test.create_client_from_file(200, requests,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult-error-invalid-"
                                                              "data-payload-422.json")

        result = self.adyen.checkout.modifications_api.refund_or_cancel_payment(requests,psp_reference)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payments_capture_success_mocked(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "amount": {
                "value": 2500,
                "currency": "EUR"
            },
            "reference": "YOUR_UNIQUE_REFERENCE"
        }
        psp_reference = "8536214160615591"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentcapture-"
                                                              "success.json")

        result = self.adyen.checkout.modifications_api.capture_authorised_payment(request, psp_reference)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/payments/{psp_reference}/captures',
            json=request,
            xapikey='YourXapikey',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
        )
        self.assertEqual(psp_reference, result.message["paymentPspReference"])
        self.assertIsNotNone(result.message["pspReference"])
        self.assertEqual("received", result.message['status'])
        self.assertEqual(2500, result.message['amount']['value'])

    def test_payments_capture_error_mocked(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "amount": {
                "value": 2500,
                "currency": "EUR"
            },
            "reference": "YOUR_UNIQUE_REFERENCE"
        }
        psp_reference = "8536214160615591"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentsresult-error-invalid-"
                                                              "data-payload-422.json")

        result = self.adyen.checkout.modifications_api.capture_authorised_payment(request, psp_reference)
        self.assertEqual(422, result.message['status'])
        self.assertEqual("14_018", result.message['errorCode'])
        self.assertEqual("Invalid payload provided", result.message['message'])
        self.assertEqual("validation", result.message['errorType'])

    def test_orders_success(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "orders"
                                                              "-success.json")
        result = self.adyen.checkout.orders_api.orders(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/orders',
            json=request,
            xapikey='YourXapikey',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},

        )
        self.assertEqual("8515930288670953", result.message['pspReference'])
        self.assertEqual("Success", result.message['resultCode'])
        self.assertEqual("order reference", result.message['reference'])
        self.assertEqual("EUR", result.message['remainingAmount']["currency"])
        self.assertEqual(2500, result.message['remainingAmount']['value'])

    def test_orders_cancel_success(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "orders-cancel"
                                                              "-success.json")
        result = self.adyen.checkout.orders_api.cancel_order(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/orders/cancel',
            json=request,
            xapikey='YourXapikey',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
        )
        self.assertEqual("8515931182066678", result.message['pspReference'])
        self.assertEqual("Received", result.message['resultCode'])

    def test_paymentmethods_balance_success(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentmethods"
                                                              "-balance"
                                                              "-success.json")
        result = self.adyen.checkout.orders_api.get_balance_of_gift_card(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/paymentMethods/balance',
            json=request,
            xapikey='YourXapikey',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
        )
        self.assertEqual("851611111111713K", result.message['pspReference'])
        self.assertEqual("Success", result.message['resultCode'])
        self.assertEqual(100, result.message['balance']['value'])
        self.assertEqual("EUR", result.message['balance']['currency'])

    def test_sessions_success(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "sessions"
                                                              "-success.json")
        result = self.adyen.checkout.payments_api.sessions(request)

        self.assertEqual("session-test-id", result.message['id'])
        self.assertEqual("TestReference", result.message['reference'])
        self.assertEqual("http://test-url.com", result.message['returnUrl'])

    def test_sessions_error(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "sessions"
                                                              "-error"
                                                              "-invalid"
                                                              "-data-422"
                                                              ".json")
        result = self.adyen.checkout.payments_api.sessions(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/sessions',
            json={'merchantAccount': 'YourMerchantAccount'},
            xapikey='YourXapikey',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
        )
        self.assertEqual(422, result.message['status'])
        self.assertEqual("130", result.message['errorCode'])
        self.assertEqual("validation", result.message['errorType'])

    def test_payment_link(self):
        request = {
            "reference": "YOUR_ORDER_NUMBER",
            "amount": {
                "value": 1250,
                "currency": "BRL"
            },
            "countryCode": "BR",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "shopperReference": "YOUR_UNIQUE_SHOPPER_ID",
            "shopperEmail": "test@email.com",
            "shopperLocale": "pt-BR",
            "billingAddress": {
                "street": "Roque Petroni Jr",
                "postalCode": "59000060",
                "city": "São Paulo",
                "houseNumberOrName": "999",
                "country": "BR",
                "stateOrProvince": "SP"
            },
            "deliveryAddress": {
                "street": "Roque Petroni Jr",
                "postalCode": "59000060",
                "city": "São Paulo",
                "houseNumberOrName": "999",
                "country": "BR",
                "stateOrProvince": "SP"
            }
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentlinks"
                                                              "-success"
                                                              ".json")
        result = self.adyen.checkout.payment_links_api.payment_links(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.baseUrl}/paymentLinks',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            xapikey='YourXapikey',
            json=request
        )
        self.assertEqual("YOUR_ORDER_NUMBER", result.message["reference"])

    def test_get_payment_link(self):
        id = "PL61C53A8B97E6915A"
        self.adyen.client = self.test.create_client_from_file(200, None,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "getpaymenlinks"
                                                              "-succes.json")
        result = self.adyen.checkout.payment_links_api.get_payment_link(id)
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.baseUrl}/paymentLinks/{id}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            xapikey="YourXapikey",
            json=None
        )
        self.assertEqual("TestMerchantCheckout", result.message["merchantAccount"])

    def test_update_payment_link(self):
        id = "PL61C53A8B97E6915A"
        request = {
            "status": "expired"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/checkout"
                                                              "/updatepaymentlinks"
                                                              "-success.json")
        result = self.adyen.checkout.payment_links_api.update_payment_link(request, id)
        self.adyen.client.http_client.request.assert_called_once_with(
            'PATCH',
            f'{self.baseUrl}/paymentLinks/{id}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            xapikey="YourXapikey",
            json=request
        )
        self.assertEqual("expired",result.message["status"])




from .base import AdyenServiceBase


class AdyenBinlookupApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenBinlookupApi, self).__init__(client=client)
        self.service = "binlookup"
        self.baseUrl = "https://pal-test.adyen.com/pal/servlet/BinLookup/v52"

    def get3ds_availability(self, request, idempotency_key=None, **kwargs):
        """
        Check if 3D Secure is available
        """
        endpoint = self.baseUrl + f"/get3dsAvailability"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_cost_estimate(self, request, idempotency_key=None, **kwargs):
        """
        Get a fees cost estimate
        """
        endpoint = self.baseUrl + f"/getCostEstimate"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class TerminalActionsTerminalLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(TerminalActionsTerminalLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def create_terminal_action(self, request, idempotency_key=None, **kwargs):
        """
        Create a terminal action
        """
        endpoint = self.baseUrl + f"/terminals/scheduleActions"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




#!/bin/python

from __future__ import absolute_import, division, unicode_literals

from . import util
from .exceptions import (
    AdyenAPICommunicationError,
    AdyenAPIAuthenticationError,
    AdyenAPIUnprocessableEntity,
    AdyenAPIInvalidPermission,
    AdyenAPIValidationError,
    AdyenInvalidRequestError,
    AdyenError
)
from .client import AdyenClient
from .services import (
    AdyenBase,
    AdyenPaymentsApi,
    AdyenBinlookupApi,
    AdyenRecurringApi,
    AdyenPayoutsApi,
    AdyenManagementApi,
    AdyenCheckoutApi,
    AdyenTerminalApi,
    AdyenLegalEntityManagementApi,
    AdyenDataProtectionApi,
    AdyenTransfersApi,
    AdyenStoredValueApi,
    AdyenBalancePlatformApi,
    AdyenDisputesApi,
)

from .httpclient import HTTPClient


class Adyen(AdyenBase):
    def __init__(self, **kwargs):
        self.client = AdyenClient(**kwargs)
        self.payment = AdyenPaymentsApi(client=self.client)
        self.binlookup = AdyenBinlookupApi(client=self.client)
        self.payout = AdyenPayoutsApi(client=self.client)
        self.recurring = AdyenRecurringApi(client=self.client)
        self.checkout = AdyenCheckoutApi(client=self.client)
        self.terminal = AdyenTerminalApi(client=self.client)
        self.management = AdyenManagementApi(client=self.client)
        self.legalEntityManagement = AdyenLegalEntityManagementApi(client=self.client)
        self.dataProtection = AdyenDataProtectionApi(client=self.client)
        self.transfers = AdyenTransfersApi(client=self.client)
        self.storedValue = AdyenStoredValueApi(client=self.client)
        self.balancePlatform = AdyenBalancePlatformApi(client=self.client)
        self.disputes = AdyenDisputesApi(client=self.client)


_base_adyen_obj = Adyen()
recurring = _base_adyen_obj.recurring
payment = _base_adyen_obj.payment
payout = _base_adyen_obj.payout
checkout = _base_adyen_obj.checkout
binlookup = _base_adyen_obj.binlookup
terminal = _base_adyen_obj.terminal
management = _base_adyen_obj.management
legalEntityManagement = _base_adyen_obj.legalEntityManagement
dataProtection = _base_adyen_obj.dataProtection
transfers = _base_adyen_obj.transfers
storedValue = _base_adyen_obj.storedValue
balancePlatform = _base_adyen_obj.balancePlatform
disputes = _base_adyen_obj.disputes



import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestManagement(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    transfers_url = adyen.transfers.transfers_api.baseUrl

    def test_transfer_fund(self):
        request = {
            "amount": {
                "value": 110000,
                "currency": "EUR"
            },
            "balanceAccountId": "BAB8B2C3D4E5F6G7H8D9J6GD4",
            "category": "bank",
            "counterparty": {
                "bankAccount": {
                    "accountHolder": {
                        "fullName": "A. Klaassen",
                        "address": {
                            "city": "San Francisco",
                            "country": "US",
                            "postalCode": "94678",
                            "stateOrProvince": "CA",
                            "street": "Brannan Street",
                            "street2": "274"
                        }
                    }
                },
                "accountIdentification": {
                    "type": "numberAndBic",
                    "accountNumber": "123456789",
                    "bic": "BOFAUS3NXXX"
                }
            },
            "priority": "wire",
            "referenceForBeneficiary": "Your reference sent to the beneficiary",
            "reference": "Your internal reference for the transfer",
            "description": "Your description for the transfer"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/transfers/"
                                                              "make-transfer-response.json")
        result = self.adyen.transfers.transfers_api.transfer_funds(request)

        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.transfers_url}/transfers',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_get_all_transactions(self):
        self.adyen.client = self.test.create_client_from_file(200, None, "test/mocks/transfers/"
                                                                         "get-all-transactions.json")

        result = self.adyen.transfers.transactions_api.get_all_transactions()
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.transfers_url}/transactions',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )

    def test_get_transaction(self):
        transacion_id="123"
        self.adyen.client = self.test.create_client_from_file(200, None, "test/mocks/transfers/"
                                                                         "get-transaction.json")
        result = self.adyen.transfers.transactions_api.get_transaction(transacion_id)
        self.adyen.client.http_client.request.assert_called_once_with(
            'GET',
            f'{self.transfers_url}/transactions/{transacion_id}',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=None,
            xapikey="YourXapikey"
        )




from __future__ import absolute_import, division, unicode_literals

import base64
import hmac
import hashlib
import binascii


def generate_notification_sig(dict_object, hmac_key):

    if not isinstance(dict_object, dict):
        raise ValueError("Must Provide dictionary object")

    hmac_key = binascii.a2b_hex(hmac_key)

    request_dict = dict(dict_object)
    request_dict['value'] = request_dict['amount']['value']
    request_dict['currency'] = request_dict['amount']['currency']

    element_orders = [
        'pspReference',
        'originalReference',
        'merchantAccountCode',
        'merchantReference',
        'value',
        'currency',
        'eventCode',
        'success',
    ]

    signing_string = ':'.join(map(str, (request_dict.get(element, '') for element in element_orders)))

    hm = hmac.new(hmac_key, signing_string.encode('utf-8'), hashlib.sha256)
    return base64.b64encode(hm.digest())


def is_valid_hmac_notification(dict_object, hmac_key):
    dict_object = dict_object.copy()

    if 'notificationItems' in dict_object:
        dict_object = dict_object['notificationItems'][0]['NotificationRequestItem']

    if 'additionalData' in dict_object:
        if dict_object['additionalData']['hmacSignature'] == "":
            raise ValueError("Must Provide hmacSignature in additionalData")
        else:
            expected_sign = dict_object['additionalData']['hmacSignature']
            del dict_object['additionalData']
            merchant_sign = generate_notification_sig(dict_object, hmac_key)
            merchant_sign_str = merchant_sign.decode("utf-8")
            return hmac.compare_digest(merchant_sign_str, expected_sign)


def get_query(query_parameters):
    return '?' + '&'.join(["{}={}".format(k, v) for k, v in query_parameters.items()])



import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestCheckout(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    data_protection_url = adyen.dataProtection.baseUrl
    lib_version = settings.LIB_VERSION

    def test_data_erasure(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "pspReference": "9915520502347613",
            "forceErasure": True
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/dataProtection/erasure-response.json")
        result = self.adyen.dataProtection.request_subject_erasure(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.data_protection_url}'
            '/requestSubjectErasure',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            xapikey="YourXapikey",
            json=request
        )
        self.assertEqual("SUCCESS", result.message["result"])



from ..base import AdyenServiceBase


class UtilityApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(UtilityApi, self).__init__(client=client)
        self.service = "checkout"
        self.baseUrl = "https://checkout-test.adyen.com/v71"

    def get_apple_pay_session(self, request, idempotency_key=None, **kwargs):
        """
        Get an Apple Pay session
        """
        endpoint = self.baseUrl + f"/applePay/sessions"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def origin_keys(self, request, idempotency_key=None, **kwargs):
        """
        Create originKey values for domains
        """
        endpoint = self.baseUrl + f"/originKeys"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class PaymentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PaymentsApi, self).__init__(client=client)
        self.service = "checkout"
        self.baseUrl = "https://checkout-test.adyen.com/v71"

    def get_result_of_payment_session(self, sessionId, idempotency_key=None, **kwargs):
        """
        Get the result of a payment session
        """
        endpoint = self.baseUrl + f"/sessions/{sessionId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def card_details(self, request, idempotency_key=None, **kwargs):
        """
        Get the list of brands on the card
        """
        endpoint = self.baseUrl + f"/cardDetails"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def donations(self, request, idempotency_key=None, **kwargs):
        """
        Start a transaction for donations
        """
        endpoint = self.baseUrl + f"/donations"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def payment_methods(self, request, idempotency_key=None, **kwargs):
        """
        Get a list of available payment methods
        """
        endpoint = self.baseUrl + f"/paymentMethods"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def payments(self, request, idempotency_key=None, **kwargs):
        """
        Start a transaction
        """
        endpoint = self.baseUrl + f"/payments"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def payments_details(self, request, idempotency_key=None, **kwargs):
        """
        Submit details for a payment
        """
        endpoint = self.baseUrl + f"/payments/details"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def sessions(self, request, idempotency_key=None, **kwargs):
        """
        Create a payment session
        """
        endpoint = self.baseUrl + f"/sessions"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import Adyen
import unittest
try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestModifications(unittest.TestCase):
    ady = Adyen.Adyen()

    client = ady.client
    test = BaseTest(ady)
    client.username = "YourWSUser"
    client.password = "YourWSPassword"
    client.platform = "test"

    def test_capture_success(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['modificationAmount'] = {"value": "1234", "currency": "EUR"}
        request['originalReference'] = "YourOriginalReference"
        self.ady.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'capture-success'
                                                            '.json')
        result = self.ady.payment.modifications_api.capture(request)
        self.assertEqual("[capture-received]", result.message['response'])

    def test_capture_error_167(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['modificationAmount'] = {"value": "1234", "currency": "EUR"}
        request['originalReference'] = "YourOriginalReference"
        self.ady.client = self.test.create_client_from_file(422, request,
                                                            'test/mocks/'
                                                            'capture-error-167'
                                                            '.json')
        self.assertRaisesRegex(
            Adyen.AdyenAPIUnprocessableEntity,
            "AdyenAPIUnprocessableEntity:{'status': 422, 'errorCode': '167', 'message': 'Original pspReference required for this operation', 'errorType': 'validation'}",
            self.ady.payment.modifications_api.capture,
            request
        )

    def test_cancel_or_refund_received(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['originalReference'] = "YourOriginalReference"
        self.ady.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'cancelOrRefund'
                                                            '-received.json')
        result = self.ady.payment.modifications_api.cancel_or_refund(request)
        self.assertEqual("[cancelOrRefund-received]",
                         result.message['response'])

    def test_refund_received(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['originalReference'] = "YourOriginalReference"
        request['modificationAmount'] = {"value": "1234", "currency": "EUR"}
        self.ady.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'refund-received'
                                                            '.json')
        result = self.ady.payment.modifications_api.refund(request)
        self.assertEqual("[refund-received]", result.message['response'])

    def test_cancel_received(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['originalReference'] = "YourOriginalReference"
        self.ady.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'cancel-received'
                                                            '.json')
        result = self.ady.payment.modifications_api.cancel(request)
        self.assertEqual("[cancel-received]", result.message['response'])

    def test_adjust_authorisation_received(self):
        request = {}
        request['merchantAccount'] = "YourMerchantAccount"
        request['reference'] = "YourReference"
        request['modificationAmount'] = {"value": "1234", "currency": "EUR"}
        request['originalReference'] = "YourOriginalReference"
        self.ady.client = self.test.create_client_from_file(200, request,
                                                            'test/mocks/'
                                                            'adjust-'
                                                            'authorisation-'
                                                            'received.json')
        result = self.ady.payment.modifications_api.adjust_authorisation(request)
        self.assertEqual("[adjustAuthorisation-received]",
                         result.message['response'])


TestModifications.client.http_force = "requests"
suite = unittest.TestLoader().loadTestsFromTestCase(TestModifications)
unittest.TextTestRunner(verbosity=2).run(suite)
TestModifications.client.http_force = "pycurl"
TestModifications.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestModifications)
unittest.TextTestRunner(verbosity=2).run(suite)
TestModifications.client.http_force = "other"
TestModifications.client.http_init = False
suite = unittest.TestLoader().loadTestsFromTestCase(TestModifications)
unittest.TextTestRunner(verbosity=2).run(suite)



from ..base import AdyenServiceBase


class PaymentsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PaymentsApi, self).__init__(client=client)
        self.service = "payments"
        self.baseUrl = "https://pal-test.adyen.com/pal/servlet/Payment/v68"

    def authorise(self, request, idempotency_key=None, **kwargs):
        """
        Create an authorisation
        """
        endpoint = self.baseUrl + f"/authorise"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def authorise3d(self, request, idempotency_key=None, **kwargs):
        """
        Complete a 3DS authorisation
        """
        endpoint = self.baseUrl + f"/authorise3d"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def authorise3ds2(self, request, idempotency_key=None, **kwargs):
        """
        Complete a 3DS2 authorisation
        """
        endpoint = self.baseUrl + f"/authorise3ds2"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_authentication_result(self, request, idempotency_key=None, **kwargs):
        """
        Get the 3DS authentication result
        """
        endpoint = self.baseUrl + f"/getAuthenticationResult"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def retrieve3ds2_result(self, request, idempotency_key=None, **kwargs):
        """
        Get the 3DS2 authentication result
        """
        endpoint = self.baseUrl + f"/retrieve3ds2Result"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase
from .initialization_api import InitializationApi
from .instant_payouts_api import InstantPayoutsApi
from .reviewing_api import ReviewingApi


class AdyenPayoutsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPayoutsApi, self).__init__(client=client)
        self.initialization_api = InitializationApi(client=client)
        self.instant_payouts_api = InstantPayoutsApi(client=client)
        self.reviewing_api = ReviewingApi(client=client)



import unittest
from json import load
import Adyen
from Adyen import settings
from Adyen.util import (
    generate_notification_sig,
    is_valid_hmac_notification,
    get_query
)
try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class UtilTest(unittest.TestCase):
    adyen = Adyen.Adyen()
    client = adyen.client

    def test_notification_request_item_hmac(self):
        request = {
            "pspReference": "7914073381342284",
            "merchantReference": "TestPayment-1407325143704",
            "merchantAccountCode": "TestMerchant",
            "amount": {
                "currency": "EUR",
                "value": 1130
            },
            "eventCode": "AUTHORISATION",
            "success": "true",
            "eventDate": "2019-05-06T17:15:34.121+02:00",
            "operations": [
                "CANCEL",
                "CAPTURE",
                "REFUND"
            ],
            "paymentMethod": "visa",
        }
        key = "44782DEF547AAA06C910C43932B1EB0C" \
              "71FC68D9D0C057550C48EC2ACF6BA056"
        hmac_calculation = generate_notification_sig(request, key)
        hmac_calculation_str = hmac_calculation.decode("utf-8")
        expected_hmac = "coqCmt/IZ4E3CzPvMY8zTjQVL5hYJUiBRg8UU+iCWo0="
        self.assertTrue(hmac_calculation_str != "")
        self.assertEqual(hmac_calculation_str, expected_hmac)
        request['additionalData'] = {'hmacSignature': hmac_calculation_str}
        hmac_validate = is_valid_hmac_notification(request, key)
        self.assertIn('additionalData', request)
        self.assertDictEqual(request['additionalData'],
                             {'hmacSignature': hmac_calculation_str})
        self.assertTrue(hmac_validate)

    def test_webhooks_with_slashes(self):
        hmac_key = "74F490DD33F7327BAECC88B2947C011FC02D014A473AAA33A8EC93E4DC069174"
        with open('test/mocks/util/backslash_notification.json') as file:
            backslash_notification = load(file)
            self.assertTrue(is_valid_hmac_notification(backslash_notification, hmac_key))
        with open('test/mocks/util/colon_notification.json') as file:
            colon_notification = load(file)
            self.assertTrue(is_valid_hmac_notification(colon_notification, hmac_key))
        with open('test/mocks/util/forwardslash_notification.json') as file:
            forwardslash_notification = load(file)
            self.assertTrue(is_valid_hmac_notification(forwardslash_notification, hmac_key))
        with open('test/mocks/util/mixed_notification.json') as file:
            mixed_notification = load(file)
            self.assertTrue(is_valid_hmac_notification(mixed_notification, hmac_key))


    def test_query_string_creation(self):
        query_parameters = {
            "pageSize":7,
            "pageNumber":3
        }
        query_string = get_query(query_parameters)
        self.assertEqual(query_string,'?pageSize=7&pageNumber=3')

    def test_passing_xapikey_in_method(self):
        request = {'merchantAccount': "YourMerchantAccount"}
        self.test = BaseTest(self.adyen)
        self.client.platform = "test"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/"
                                                              "checkout/"
                                                              "paymentmethods"
                                                              "-success.json")
        result = self.adyen.checkout.payments_api.payment_methods(request, xapikey="YourXapikey")
        self.assertEqual("AliPay", result.message['paymentMethods'][0]['name'])
        self.assertEqual("Credit Card",
                         result.message['paymentMethods'][2]['name'])
        self.assertEqual("Credit Card via AsiaPay",
                         result.message['paymentMethods'][3]['name'])

    def test_custom_version(self):
        self.client.api_checkout_version = 60
        request = {'merchantAccount': "YourMerchantAccount"}
        self.test = BaseTest(self.adyen)
        self.client.platform = "test"
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                            "test/mocks/"
                                                            "checkout/"
                                                            "paymentmethods"
                                                            "-success.json")
        result = self.adyen.checkout.payments_api.payment_methods(request, xapikey="YourXapikey")
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'https://checkout-test.adyen.com/v{self.client.api_checkout_version}/paymentMethods',
            headers={'adyen-library-name': settings.LIB_NAME, 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )


from .base import AdyenServiceBase


class AdyenDisputesApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenDisputesApi, self).__init__(client=client)
        self.service = "disputes"
        self.baseUrl = "https://ca-test.adyen.com/ca/services/DisputeService/v30"

    def accept_dispute(self, request, idempotency_key=None, **kwargs):
        """
        Accept a dispute
        """
        endpoint = self.baseUrl + f"/acceptDispute"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def defend_dispute(self, request, idempotency_key=None, **kwargs):
        """
        Defend a dispute
        """
        endpoint = self.baseUrl + f"/defendDispute"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def delete_dispute_defense_document(self, request, idempotency_key=None, **kwargs):
        """
        Delete a defense document
        """
        endpoint = self.baseUrl + f"/deleteDisputeDefenseDocument"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def retrieve_applicable_defense_reasons(self, request, idempotency_key=None, **kwargs):
        """
        Get applicable defense reasons
        """
        endpoint = self.baseUrl + f"/retrieveApplicableDefenseReasons"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def supply_defense_document(self, request, idempotency_key=None, **kwargs):
        """
        Supply a defense document
        """
        endpoint = self.baseUrl + f"/supplyDefenseDocument"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class PCIQuestionnairesApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(PCIQuestionnairesApi, self).__init__(client=client)
        self.service = "legalEntityManagement"
        self.baseUrl = "https://kyc-test.adyen.com/lem/v3"

    def get_pci_questionnaire_details(self, id, idempotency_key=None, **kwargs):
        """
        Get PCI questionnaire details
        """
        endpoint = self.baseUrl + f"/legalEntities/{id}/pciQuestionnaires"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_pci_questionnaire(self, id, pciid, idempotency_key=None, **kwargs):
        """
        Get PCI questionnaire
        """
        endpoint = self.baseUrl + f"/legalEntities/{id}/pciQuestionnaires/{pciid}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def generate_pci_questionnaire(self, request, id, idempotency_key=None, **kwargs):
        """
        Generate PCI questionnaire
        """
        endpoint = self.baseUrl + f"/legalEntities/{id}/pciQuestionnaires/generatePciTemplates"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def sign_pci_questionnaire(self, request, id, idempotency_key=None, **kwargs):
        """
        Sign PCI questionnaire
        """
        endpoint = self.baseUrl + f"/legalEntities/{id}/pciQuestionnaires/signPciTemplates"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




import Adyen
import unittest
from Adyen import settings

try:
    from BaseTest import BaseTest
except ImportError:
    from .BaseTest import BaseTest


class TestManagement(unittest.TestCase):
    adyen = Adyen.Adyen()

    client = adyen.client
    test = BaseTest(adyen)
    client.xapikey = "YourXapikey"
    client.platform = "test"
    stored_value_url = adyen.storedValue.baseUrl

    def issue(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE_ID",
            "paymentMethod": {
                "type": "valuelink"
            },
            "giftCardPromoCode": "1324",
            "reference": "YOUR_REFERENCE"
        }

        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/storedValue/issue-giftcard.json")
        result = self.adyen.storedValue.issue(request)
        self.assertEqual(result.message['paymentMethod']['type'], 'givex')
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/issue',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_activate_giftcard(self):
        request = {
            "status": "active",
            "amount": {
                "currency": "USD",
                "value": 1000
            },
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE_ID",
            "paymentMethod": {
                "type": "svs",
                "number": "6006491286999921374",
                "securityCode": "1111"
            },
            "reference": "YOUR_REFERENCE"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/storedValue/activate-giftcards.json")
        result = self.adyen.storedValue.change_status(request)
        self.assertEqual(result.message['currentBalance']['value'], 1000)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/changeStatus',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_load_funds(self):
        request = {
            "amount": {
                "currency": "USD",
                "value": 2000
            },
            "loadType": "merchandiseReturn",
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE_ID",
            "paymentMethod": {
                "type": "svs",
                "number": "6006491286999921374",
                "securityCode": "1111"
            },
            "reference": "YOUR_REFERENCE"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/storedValue/load-funds.json")
        result = self.adyen.storedValue.load(request)
        self.assertEqual(result.message['resultCode'], 'Success')
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/load',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_check_balance(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE_ID",
            "paymentMethod": {
                "type": "svs",
                "number": "603628672882001915092",
                "securityCode": "5754"
            },
            "reference": "YOUR_REFERENCE"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/storedValue/check-balance.json")
        result = self.adyen.storedValue.check_balance(request)
        self.assertEqual(result.message['currentBalance']['value'], 5600)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/checkBalance',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_merge_balance(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "store": "YOUR_STORE_ID",
            "sourcePaymentMethod": {
                "number": "7777182708544835",
                "securityCode": "2329"
            },
            "paymentMethod": {
                "type": "valuelink",
                "number": "8888182708544836",
                "securityCode": "2330"
            },
            "reference": "YOUR_REFERENCE"
        }
        self.adyen.client = self.test.create_client_from_file(200, request, "test/mocks/storedValue/merge-balance.json")
        result = self.adyen.storedValue.merge_balance(request)
        self.assertEqual(result.message['pspReference'], "881564657480267D")
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/mergeBalance',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )

    def test_void_transaction(self):
        request = {
            "merchantAccount": "YOUR_MERCHANT_ACCOUNT",
            "originalReference": "851564654294247B",
            "reference": "YOUR_REFERENCE"
        }
        self.adyen.client = self.test.create_client_from_file(200, request,
                                                              "test/mocks/storedValue/undo-transaction.json")
        result = self.adyen.storedValue.void_transaction(request)
        self.adyen.client.http_client.request.assert_called_once_with(
            'POST',
            f'{self.stored_value_url}/voidTransaction',
            headers={'adyen-library-name': 'adyen-python-api-library', 'adyen-library-version': settings.LIB_VERSION},
            json=request,
            xapikey="YourXapikey"
        )



from ..base import AdyenServiceBase


class SplitConfigurationMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(SplitConfigurationMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def delete_split_configuration(self, merchantId, splitConfigurationId, idempotency_key=None, **kwargs):
        """
        Delete a split configuration
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def delete_split_configuration_rule(self, merchantId, splitConfigurationId, ruleId, idempotency_key=None, **kwargs):
        """
        Delete a split configuration rule
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}/rules/{ruleId}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_split_configurations(self, merchantId, idempotency_key=None, **kwargs):
        """
        Get a list of split configurations
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_split_configuration(self, merchantId, splitConfigurationId, idempotency_key=None, **kwargs):
        """
        Get a split configuration
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_split_configuration_description(self, request, merchantId, splitConfigurationId, idempotency_key=None, **kwargs):
        """
        Update split configuration description
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_split_conditions(self, request, merchantId, splitConfigurationId, ruleId, idempotency_key=None, **kwargs):
        """
        Update split conditions
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}/rules/{ruleId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def update_split_logic(self, request, merchantId, splitConfigurationId, ruleId, splitLogicId, idempotency_key=None, **kwargs):
        """
        Update the split logic
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}/rules/{ruleId}/splitLogic/{splitLogicId}"
        method = "PATCH"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_split_configuration(self, request, merchantId, idempotency_key=None, **kwargs):
        """
        Create a split configuration
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def create_rule(self, request, merchantId, splitConfigurationId, idempotency_key=None, **kwargs):
        """
        Create a rule
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/splitConfigurations/{splitConfigurationId}"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

